--*****************************************************************************
--*  Copyright (C) 2012 by Michael Fischer
--*
--*  All rights reserved.
--*
--*  Redistribution and use in source and binary forms, with or without 
--*  modification, are permitted provided that the following conditions 
--*  are met:
--*  
--*  1. Redistributions of source code must retain the above copyright 
--*     notice, this list of conditions and the following disclaimer.
--*  2. Redistributions in binary form must reproduce the above copyright
--*     notice, this list of conditions and the following disclaimer in the 
--*     documentation and/or other materials provided with the distribution.
--*  3. Neither the name of the author nor the names of its contributors may 
--*     be used to endorse or promote products derived from this software 
--*     without specific prior written permission.
--*
--*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
--*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
--*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
--*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
--*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
--*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
--*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
--*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
--*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
--*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
--*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
--*  SUCH DAMAGE.
--*
--*****************************************************************************
--*  History:
--*
--*  14.07.2012  mifi  First Version, tested with an Altera DE1 board.
--*                    Based on the verilog Terasic example.
--*****************************************************************************


--*****************************************************************************
--*  DEFINE: Library                                                          *
--*****************************************************************************

library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.numeric_std.all;


--*****************************************************************************
--*  DEFINE: Entity                                                           *
--*****************************************************************************

entity is61lv256al_if is
	port (
          -- Avalon slave bus
		    clk          : in    std_logic := '0';
          reset        : in    std_logic := '0';
		    address      : in    std_logic_vector(17 downto 0) := (others => '0');
          chipselect_n : in    std_logic := '1';
          byteenable_n : in    std_logic_vector(1 downto 0) := (others => '0');
          write_n      : in    std_logic := '1';
          writedata    : in    std_logic_vector(15 downto 0) := (others => '0');
          read_n       : in    std_logic := '1';
          readdata     : out   std_logic_vector(15 downto 0);
      
          -- Device bus
		    SRAM_ADDR    : out   std_logic_vector(17 downto 0);
		    SRAM_DATA    : inout std_logic_vector(15 downto 0) := (others => '0');
		    SRAM_WE_N    : out   std_logic;
		    SRAM_OE_N    : out   std_logic;
		    SRAM_CE_N    : out   std_logic;
		    SRAM_BE_N    : out   std_logic_vector(1 downto 0)
	     );
end entity is61lv256al_if;

--*****************************************************************************
--*  DEFINE: Architecture                                                     *
--*****************************************************************************

architecture syn of is61lv256al_if is

   --
   -- Define all components which are included here
   --

   --
   -- Define all local signals (like static data) here
   --

begin

   SRAM_ADDR <= address;
   SRAM_WE_N <= write_n;
   SRAM_OE_N <= read_n;
   SRAM_CE_N <= chipselect_n;
   SRAM_BE_N <= byteenable_n;

   SRAM_DATA <= writedata when (write_n = '0') else (others => 'Z');   
   readdata  <= SRAM_DATA;

end architecture syn;

-- *** EOF ***
